README
======

.. image:: https://badge.fury.io/py/dtool-info.svg
   :target: http://badge.fury.io/py/dtool-info
   :alt: PyPi package

Dtool plugin for getting information about datasets

Installation
------------

.. code-block:: bash

    pip install dtool-info

Example usage
-------------

Listing datasets in ``~/my_dataset`` directory::

    dtool ls ~/my_datasets

Getting summary information about a dataset::

    dtool summary ~/my_datasets/example_dataset

See the `dtool documentation <http://dtool.readthedocs.io>`_ for more detail.
